package org.openlp.android2;

import android.app.Activity;
import android.content.Intent;
import android.support.v7.app.ActionBarActivity;
import android.app.ActionBar;
import android.app.Fragment;
import android.app.FragmentManager;

import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.support.v4.widget.DrawerLayout;

import org.openlp.android2.activities.ConnectionActivity;
import org.openlp.android2.activities.SettingsActivity;
import org.openlp.android2.common.NavigationOptions;
import org.openlp.android2.dialogs.AlertDisplayDialog;
import org.openlp.android2.dialogs.BlankDisplayDialog;
import org.openlp.android2.fragments.AboutFragment;
import org.openlp.android2.fragments.HomeFragment;
import org.openlp.android2.fragments.LiveListFragment;
import org.openlp.android2.fragments.LiveWebFragment;
import org.openlp.android2.fragments.NavigationDrawerFragment;
import org.openlp.android2.fragments.ServiceListFragment;
import org.openlp.android2.fragments.StageWebFragment;


public class OpenLP extends ActionBarActivity
        implements NavigationDrawerFragment.NavigationDrawerCallbacks {

    /**
     * Fragment managing the behaviors, interactions and presentation of the navigation drawer.
     */
    private NavigationDrawerFragment mNavigationDrawerFragment;

    /**
     * Used to store the last screen title. For use in {@link #restoreActionBar()}.
     */
    private CharSequence mTitle;
    private boolean backArrowActive = false;
    private Menu dropdownMenu;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        mNavigationDrawerFragment = (NavigationDrawerFragment)
                getSupportFragmentManager().findFragmentById(R.id.navigation_drawer);
        mTitle = getTitle();

        // Set up the drawer.
        mNavigationDrawerFragment.setUp(
                R.id.navigation_drawer,
                (DrawerLayout) findViewById(R.id.drawer_layout));
    }

    @Override
    public void onNavigationDrawerItemSelected(int position) {
        // update the main content by replacing fragments
        FragmentManager fragmentManager = getFragmentManager();
        switch (position) {
            case NavigationOptions.Home:
                fragmentManager.beginTransaction()
                        .replace(R.id.container, HomeFragment.newInstance())
                        .commit();
                mTitle = getString(R.string.home);
                break;
            case NavigationOptions.ServiceList:
                fragmentManager.beginTransaction()
                        .replace(R.id.container, ServiceListFragment.newInstance())
                        .commit();
                mTitle = getString(R.string.service_list);
                break;
            case NavigationOptions.LiveList:
                fragmentManager.beginTransaction()
                        .replace(R.id.container, LiveListFragment.newInstance())
                        .commit();
                mTitle = getString(R.string.live_list);
                break;
            case NavigationOptions.StageView:
                fragmentManager.beginTransaction()
                        .replace(R.id.container, StageWebFragment.newInstance())
                        .commit();
                mTitle = getString(R.string.stage_view);
                break;
            case NavigationOptions.LiveView:
                fragmentManager.beginTransaction()
                        .replace(R.id.container, LiveWebFragment.newInstance())
                        .commit();
                mTitle = getString(R.string.live_view);
                break;
        }
        menuVisible();
    }

    public void restoreActionBar() {

        try {
            ActionBar actionBar = getActionBar();
            //actionBar.setNavigationMode(ActionBar.NAVIGATION_MODE_STANDARD);
            actionBar.setDisplayShowTitleEnabled(true);
            actionBar.setTitle(mTitle);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public void setMenuActive(){
        backArrowActive = true;
    }

    public void menuVisible() {
        if (dropdownMenu != null){
            MenuItem checkable = dropdownMenu.findItem(R.id.action_back);
            if (checkable != null) {
                if (backArrowActive) {
                    checkable.setVisible(true);
                } else {
                    checkable.setVisible(false);
                }
            }
        }
        backArrowActive = false;
        //restoreActionBar();
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        if (!mNavigationDrawerFragment.isDrawerOpen()) {
            // Only show items in the action bar relevant to this screen
            // if the drawer is not showing. Otherwise, let the drawer
            // decide what to show in the action bar.
            getMenuInflater().inflate(R.menu.open_l, menu);
            restoreActionBar();
            return true;
        }
        return super.onCreateOptionsMenu(menu);
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        Intent intent;
        switch (item.getItemId()) {
            case R.id.action_back:
                onNavigationDrawerItemSelected(NavigationOptions.ServiceList);
                return true;
            case R.id.action_preferences:
                intent = new Intent(this, SettingsActivity.class);
                startActivity(intent);
                return true;
            case R.id.action_refresh:
                if (this.mTitle.equals(getString(R.string.service_list))) {
                    ServiceListFragment fragment = (ServiceListFragment)
                            getFragmentManager().findFragmentById(R.id.container);
                    fragment.refreshDisplay();
                } else if (this.mTitle.equals(getString(R.string.live_list)) ) {
                    LiveListFragment fragment = (LiveListFragment)
                            getFragmentManager().findFragmentById(R.id.container);
                    fragment.refreshDisplay();
                }
                return true;
            case R.id.action_blank:
                new BlankDisplayDialog().show(getFragmentManager(), "BlankDialog");
                return true;
            case R.id.action_alert:
                new AlertDisplayDialog().show(getFragmentManager(), "AlertDialog");
                return true;
            case R.id.action_about:
                getFragmentManager().beginTransaction().replace(R.id.container,
                        new AboutFragment()).commit();
            default:
                return super.onOptionsItemSelected(item);
        }
    }

    /**
     * A placeholder fragment containing a simple view.
     */
    public static class PlaceholderFragment extends Fragment {
        /**
         * The fragment argument representing the section number for this
         * fragment.
         */
        private static final String ARG_SECTION_NUMBER = "section_number";

        /**
         * Returns a new instance of this fragment for the given section
         * number.
         */
        public static PlaceholderFragment newInstance(int sectionNumber) {
            PlaceholderFragment fragment = new PlaceholderFragment();
            Bundle args = new Bundle();
            args.putInt(ARG_SECTION_NUMBER, sectionNumber);
            fragment.setArguments(args);
            return fragment;
        }

        public PlaceholderFragment() {
        }

        @Override
        public View onCreateView(LayoutInflater inflater, ViewGroup container,
                                 Bundle savedInstanceState) {
            View rootView = inflater.inflate(R.layout.fragment_main, container, false);
            return rootView;
        }

        @Override
        public void onAttach(Activity activity) {
            super.onAttach(activity);
            //((OpenLP) activity).onSectionAttached(
            //        getArguments().getInt(ARG_SECTION_NUMBER));
        }
    }

}
